package Location::Area::DoCoMo::iArea::Region;

use strict;

sub seek
{
  shift;
  seek DATA,0,0;
  my ($aid,$said) = @_;
  my ($region,$pref);
  while (my $line = <DATA>)
  {
    my @scan = $line =~ /^$aid,$said,([^,]+),([^,]+),/;
    if (@scan)
    {
      ($region,$pref) = @scan;
      last;
    }
  }
  return ($region,$pref);
}

1;
__DATA__
001,00,北海道,北海道,函館/渡島
001,01,北海道,北海道,江差/桧山
002,01,北海道,北海道,小樽/後志
002,02,北海道,北海道,苫小牧/室蘭
002,03,北海道,北海道,岩見沢/空知
002,04,北海道,北海道,浦河/日高
002,05,北海道,北海道,北広島/恵庭/千歳
002,06,北海道,北海道,札幌駅周辺
002,07,北海道,北海道,大通公園周辺
002,08,北海道,北海道,すすきの
002,09,北海道,北海道,中島公園周辺
002,10,北海道,北海道,桑園/円山/伏見
002,11,北海道,北海道,大通東
002,12,北海道,北海道,山鼻/藻岩周辺
002,13,北海道,北海道,北24条/北大周辺
002,14,北海道,北海道,麻生/新道北
002,15,北海道,北海道,東区
002,16,北海道,北海道,琴似/八軒
002,17,北海道,北海道,手稲/宮の沢/西野
002,18,北海道,北海道,平岸/澄川/西岡
002,19,北海道,北海道,豊平/月寒/清田
002,20,北海道,北海道,白石
002,21,北海道,北海道,厚別
002,22,北海道,北海道,南区/盤渓
002,23,北海道,北海道,江別/石狩
003,00,北海道,北海道,旭川/上川
003,01,北海道,北海道,稚内/宗谷
003,02,北海道,北海道,留萌
004,00,北海道,北海道,網走/北見/紋別
005,00,北海道,北海道,帯広/十勝
006,00,北海道,北海道,釧路
006,01,北海道,北海道,根室
007,00,東北,岩手,一ノ関
008,00,東北,岩手,盛岡
009,00,東北,岩手,沿岸
010,00,東北,青森,八戸
011,00,東北,青森,青森
012,00,東北,青森,弘前
013,00,東北,秋田,大館
014,00,東北,秋田,秋田
015,00,東北,秋田,横手
016,00,東北,福島,福島
016,01,東北,福島,郡山
017,00,東北,福島,会津若松/喜多方
018,00,東北,福島,いわき
019,00,東北,宮城,仙台市周辺
019,01,東北,宮城,仙南
020,00,東北,宮城,石巻/松島/気仙沼
021,00,東北,宮城,大崎
022,00,東北,山形,米沢
023,00,東北,山形,山形
024,00,東北,山形,新庄
025,00,東北,山形,鶴岡
026,00,関東甲信越,栃木,小山
027,00,関東甲信越,栃木,宇都宮
028,00,関東甲信越,栃木,中禅寺湖/日光周辺
029,00,関東甲信越,栃木,鬼怒川/川治
030,00,関東甲信越,栃木,塩原/大田原周辺
031,00,関東甲信越,栃木,那須
032,00,関東甲信越,群馬,尾瀬
033,00,関東甲信越,群馬,前橋/伊勢崎
034,00,関東甲信越,群馬,太田/館林
035,00,関東甲信越,群馬,高崎
036,00,関東甲信越,群馬,伊香保/榛名/草津
037,00,関東甲信越,群馬,沼田/水上
038,00,関東甲信越,新潟,湯沢/奥只見
039,00,関東甲信越,新潟,糸魚川/直江津
040,00,関東甲信越,新潟,長岡
041,00,関東甲信越,新潟,新潟/新津
042,00,関東甲信越,新潟,新発田/村上
043,00,関東甲信越,新潟,佐渡
044,00,関東甲信越,千葉,千葉
044,01,関東甲信越,千葉,船橋/浦安
045,00,関東甲信越,千葉,木更津
046,00,関東甲信越,千葉,内房
047,00,関東甲信越,千葉,外房
048,00,関東甲信越,千葉,茂原/九十九里
048,01,関東甲信越,千葉,八日市場
049,00,関東甲信越,千葉,成田/佐倉
050,00,関東甲信越,千葉,銚子周辺
051,00,関東甲信越,千葉,松戸/柏/野田
052,00,関東甲信越,茨城,取手/つくば
053,00,関東甲信越,茨城,古河
054,00,関東甲信越,茨城,土浦
055,00,関東甲信越,茨城,水戸
056,00,関東甲信越,茨城,日立周辺
057,00,関東甲信越,東京,東京駅周辺
057,01,関東甲信越,東京,有楽町/日比谷
057,02,関東甲信越,東京,秋葉原
057,03,関東甲信越,東京,神田
057,04,関東甲信越,東京,御茶ノ水/神保町
057,05,関東甲信越,東京,麹町/市ヶ谷
058,00,関東甲信越,東京,銀座
058,02,関東甲信越,東京,日本橋
058,04,関東甲信越,東京,人形町/浜町
058,05,関東甲信越,東京,築地
058,06,関東甲信越,東京,月島/晴海/豊洲
058,07,関東甲信越,東京,新橋
058,08,関東甲信越,東京,浜松町/芝浦
058,09,関東甲信越,東京,田町/三田
058,10,関東甲信越,東京,品川
059,00,関東甲信越,東京,赤坂
059,01,関東甲信越,東京,青山/信濃町
059,02,関東甲信越,東京,六本木
059,03,関東甲信越,東京,西麻布
059,04,関東甲信越,東京,麻布十番
059,05,関東甲信越,東京,広尾/白金
059,06,関東甲信越,東京,お台場/有明
060,00,関東甲信越,東京,大崎/五反田
060,01,関東甲信越,東京,目黒
060,02,関東甲信越,東京,天王洲
060,03,関東甲信越,東京,大井町
060,04,関東甲信越,東京,大森
061,00,関東甲信越,東京,蒲田/羽田
061,01,関東甲信越,東京,田園調布
062,10,関東甲信越,東京,上野毛
062,11,関東甲信越,東京,下北沢
062,12,関東甲信越,東京,成城
062,13,関東甲信越,東京,明大前
062,14,関東甲信越,東京,下高井戸
062,00,関東甲信越,東京,渋谷駅周辺
062,01,関東甲信越,東京,渋谷明治通り/宮益坂
062,03,関東甲信越,東京,表参道/原宿
062,04,関東甲信越,東京,初台/代々木上原
062,05,関東甲信越,東京,恵比寿/代官山
062,06,関東甲信越,東京,中目黒
062,07,関東甲信越,東京,自由が丘
062,08,関東甲信越,東京,三軒茶屋/三宿
062,09,関東甲信越,東京,二子玉川
062,15,関東甲信越,東京,用賀/駒沢
062,16,関東甲信越,東京,世田谷/経堂
063,10,関東甲信越,東京,高円寺/阿佐ヶ谷
063,00,関東甲信越,東京,新宿東口
063,01,関東甲信越,東京,西新宿
063,02,関東甲信越,東京,新宿南口/代々木
063,03,関東甲信越,東京,新宿歌舞伎町
063,04,関東甲信越,東京,新宿１〜２丁目
063,05,関東甲信越,東京,千駄ヶ谷/信濃町
063,06,関東甲信越,東京,四谷
063,07,関東甲信越,東京,飯田橋/神楽坂
063,08,関東甲信越,東京,高田馬場/早稲田
063,09,関東甲信越,東京,中野
063,12,関東甲信越,東京,荻窪/西荻
063,14,関東甲信越,東京,練馬/西東京市
064,00,関東甲信越,東京,本郷
064,01,関東甲信越,東京,根津/千駄木
064,02,関東甲信越,東京,白山/小石川
064,03,関東甲信越,東京,大塚/目白台
064,04,関東甲信越,東京,後楽園/水道橋
065,00,関東甲信越,東京,池袋
065,01,関東甲信越,東京,目白
065,02,関東甲信越,東京,江古田
065,03,関東甲信越,東京,豊島園/豊玉
065,04,関東甲信越,東京,成増
065,05,関東甲信越,東京,王子
065,06,関東甲信越,東京,上中里
065,07,関東甲信越,東京,東十条
065,08,関東甲信越,東京,赤羽
065,09,関東甲信越,東京,田端/駒込/巣鴨
066,00,関東甲信越,東京,上野/御徒町
066,01,関東甲信越,東京,浅草
066,02,関東甲信越,東京,日暮里
066,03,関東甲信越,東京,北千住
066,04,関東甲信越,東京,青砥
066,05,関東甲信越,東京,柴又
067,00,関東甲信越,東京,両国
067,01,関東甲信越,東京,錦糸町/曳舟
067,02,関東甲信越,東京,亀戸
067,03,関東甲信越,東京,森下
067,04,関東甲信越,東京,深川
067,05,関東甲信越,東京,木場
067,06,関東甲信越,東京,辰巳/新木場
067,07,関東甲信越,東京,砂町
067,08,関東甲信越,東京,葛西臨海公園
068,00,関東甲信越,東京,吉祥寺/三鷹
068,01,関東甲信越,東京,国分寺/国立
068,02,関東甲信越,埼玉,所沢
069,00,関東甲信越,埼玉,飯能/日高
070,00,関東甲信越,埼玉,川越/東松山
070,01,関東甲信越,埼玉,和光/朝霞/富士見
071,00,関東甲信越,埼玉,大宮
071,01,関東甲信越,埼玉,浦和
071,02,関東甲信越,埼玉,川口
072,00,関東甲信越,埼玉,草加/三郷
072,01,関東甲信越,埼玉,久喜/羽生
072,02,関東甲信越,埼玉,春日部/越谷
073,00,関東甲信越,埼玉,熊谷/深谷
074,00,関東甲信越,埼玉,秩父/長瀞
075,00,関東甲信越,東京,府中/調布
075,01,関東甲信越,東京,多摩
076,00,関東甲信越,東京,八王子
077,00,関東甲信越,東京,立川
077,01,関東甲信越,東京,青梅/福生/奥多摩
078,10,関東甲信越,神奈川,八景島/金沢文庫
078,11,関東甲信越,神奈川,横浜
078,12,関東甲信越,神奈川,上大岡/港南台
078,13,関東甲信越,神奈川,大船/本郷台
078,14,関東甲信越,神奈川,戸塚
078,15,関東甲信越,神奈川,いずみ野/緑園都市
078,16,関東甲信越,神奈川,大和/瀬谷/三ツ境
078,17,関東甲信越,神奈川,中山/長津田
078,18,関東甲信越,神奈川,希望が丘/二俣川
078,19,関東甲信越,神奈川,新横浜
078,20,関東甲信越,神奈川,川崎/鶴見
078,00,関東甲信越,神奈川,溝の口/たまプラーザ/青葉台
078,01,関東甲信越,神奈川,港北ニュータウン
078,02,関東甲信越,神奈川,みなとみらい
078,03,関東甲信越,神奈川,元町/中華街
078,04,関東甲信越,神奈川,関内/伊勢佐木町
078,05,関東甲信越,神奈川,石川町
078,06,関東甲信越,神奈川,本牧/三渓園
078,07,関東甲信越,神奈川,弘明寺/井土ヶ谷
078,08,関東甲信越,神奈川,保土ヶ谷
078,09,関東甲信越,神奈川,磯子
078,21,関東甲信越,神奈川,武蔵小杉/日吉
079,00,関東甲信越,神奈川,新百合ヶ丘/登戸
080,00,関東甲信越,神奈川,鎌倉/由比/大船
081,00,関東甲信越,神奈川,横須賀/逗子
082,00,関東甲信越,神奈川,平塚/大磯
082,01,関東甲信越,神奈川,藤沢/茅ヶ崎/江ノ島
083,00,関東甲信越,神奈川,町田/相模大野
083,01,関東甲信越,神奈川,本厚木/海老名
084,00,関東甲信越,東京,大島/新島
085,00,関東甲信越,東京,三宅島/八丈島
086,00,関東甲信越,東京,小笠原諸島
087,00,関東甲信越,神奈川,小田原
088,00,関東甲信越,神奈川,箱根
089,00,関東甲信越,神奈川,真鶴/湯河原
090,00,東海,静岡,熱海/伊東/東伊豆
092,00,東海,静岡,下田/南伊豆
093,00,東海,静岡,沼津/三島/御殿場
093,01,東海,静岡,西伊豆
093,02,東海,静岡,中伊豆
094,00,関東甲信越,山梨,富士吉田
095,00,東海,静岡,富士/富士宮
096,00,関東甲信越,山梨,甲府
097,00,関東甲信越,山梨,身延線周辺
098,00,東海,静岡,静岡
098,01,東海,静岡,焼津/藤枝/志太
098,02,東海,静岡,静岡清水/庵原
099,00,東海,静岡,静岡駅周辺
100,00,東海,静岡,島田/榛原
101,00,東海,静岡,掛川/小笠
101,01,東海,静岡,磐田/袋井
102,00,関東甲信越,長野,軽井沢/小諸
103,00,関東甲信越,長野,上田/菅平
104,00,関東甲信越,長野,長野
105,00,関東甲信越,長野,戸隠/妙高
106,00,関東甲信越,長野,志賀高原/飯山
107,00,関東甲信越,長野,小海線沿線/八ヶ岳
108,00,関東甲信越,長野,諏訪
109,00,関東甲信越,長野,松本
110,00,関東甲信越,長野,上高地/乗鞍
111,00,関東甲信越,長野,大糸線沿線/北アルプス
112,00,関東甲信越,長野,伊那/天竜峡
113,00,関東甲信越,長野,木曽
114,00,東海,愛知,西区/県庁
114,01,東海,愛知,栄北
114,02,東海,愛知,栄南
114,03,東海,愛知,新栄
114,04,東海,愛知,伏見
114,05,東海,愛知,大須/上前津/金山
114,06,東海,愛知,東区
114,07,東海,愛知,北区
114,08,東海,愛知,名古屋駅
114,09,東海,愛知,中村区
114,10,東海,愛知,中川区
114,11,東海,愛知,港区
114,12,東海,愛知,熱田
114,13,東海,愛知,南区
114,14,東海,愛知,緑区
114,15,東海,愛知,塩釜口
114,16,東海,愛知,植田/原
114,17,東海,愛知,平針/赤池
114,18,東海,愛知,瑞穂区役所
114,19,東海,愛知,新瑞橋
114,20,東海,愛知,鶴舞
114,21,東海,愛知,御器所
114,22,東海,愛知,杁中
114,23,東海,愛知,石川橋
114,24,東海,愛知,八事
114,25,東海,愛知,桜山
114,26,東海,愛知,千種/今池
114,27,東海,愛知,池下/覚王山
114,28,東海,愛知,本山
114,29,東海,愛知,東山公園/星が丘
114,30,東海,愛知,一社/上社
114,31,東海,愛知,本郷/藤ヶ丘
114,32,東海,愛知,守山区
115,00,東海,愛知,東海/大府/日進/愛知郡
116,00,東海,愛知,一宮/稲沢/津島
117,00,東海,三重,四日市周辺
117,01,東海,三重,桑名周辺
117,02,東海,三重,鈴鹿/亀山
118,00,東海,愛知,瀬戸/春日井/小牧/犬山
119,00,東海,岐阜,東濃
120,00,東海,愛知,知多半島/西尾/蒲郡
121,00,東海,愛知,豊田/安城/刈谷/岡崎
122,00,東海,愛知,豊橋/渥美/奥三河
123,00,東海,静岡,浜松/浜名湖
123,01,東海,静岡,天竜/北遠
124,00,東海,岐阜,岐阜
124,01,東海,岐阜,西濃
125,00,東海,岐阜,中濃
126,00,東海,岐阜,飛騨
126,01,東海,岐阜,高山
127,00,北陸,福井,越前/鯖江/南条
128,00,北陸,福井,福井/あわら/坂井
129,00,北陸,福井,大野/勝山/永平寺
130,00,北陸,石川,小松/加賀/能美
131,01,北陸,石川,金石/内灘/金沢東
131,02,北陸,石川,金沢駅/武蔵/東山
131,03,北陸,石川,片町/香林坊
131,04,北陸,石川,兼六園/小立野/もりの里/湯涌
131,05,北陸,石川,金沢西/寺町/有松
131,06,北陸,石川,野々市/松任
132,00,北陸,石川,白山麓/手取
133,00,北陸,石川,津幡/かほく/羽咋
134,00,北陸,石川,七尾/中能登/能登島
135,00,北陸,石川,奥能登
136,00,北陸,富山,高岡/氷見/射水
137,00,北陸,富山,砺波/小矢部/南砺/五箇山
138,00,北陸,富山,富山
139,00,北陸,富山,立山
140,00,北陸,富山,滑川/魚津/黒部/宇奈月
141,00,関西,滋賀,大津市
142,00,関西,滋賀,湖東/湖南
143,00,関西,滋賀,湖北
144,00,関西,滋賀,湖西
145,00,北陸,福井,敦賀/三方五湖
146,00,北陸,福井,小浜/若狭
147,00,関西,京都,京都府北部
147,01,関西,京都,京都府中部
148,00,関西,兵庫,但馬
149,00,関西,京都,京都駅周辺
149,01,関西,京都,三条/四条
149,03,関西,京都,二条城/御所周辺
149,04,関西,京都,西院周辺
149,05,関西,京都,祇園/東山
149,07,関西,京都,銀閣寺/岡崎周辺
149,08,関西,京都,修学院/岩倉/八瀬/大原
149,12,関西,京都,桂/洛西
149,13,関西,京都,嵐山/嵯峨野
149,14,関西,京都,山科
149,15,関西,京都,北山通/金閣寺/上賀茂周辺
149,17,関西,京都,五条通周辺
149,18,関西,京都,東寺/吉祥院周辺
149,19 ,関西,京都,四条大宮
149,20,関西,京都,太秦/高雄
149,21,関西,京都,伏見/桃山/淀
150,00,関西,京都,長岡京市/向日市
151,00,関西,京都,南山城
152,00,関西,大阪,泉北
152,01,関西,大阪,泉南
152,02,関西,大阪,南河内
153,00,関西,奈良,奈良市
154,00,関西,奈良,生駒/大和郡山
155,00,関西,奈良,奈良中部
156,00,関西,奈良,奈良南部
158,00,東海,三重,上野/名張
159,00,関西,和歌山,和歌山/海南
160,00,関西,和歌山,橋本/高野山
161,00,関西,和歌山,御坊/有田
162,00,関西,和歌山,田辺
163,00,関西,和歌山,白浜周辺
164,00,関西,和歌山,枯木灘/串本周辺
165,00,関西,和歌山,那智勝浦
166,00,関西,和歌山,新宮
167,00,東海,三重,尾鷲/熊野
168,00,東海,三重,津/久居
169,00,東海,三重,松阪/紀勢
170,00,東海,三重,伊勢/鳥羽/志摩
172,00,関西,大阪,中津/大淀
172,01,関西,大阪,お初天神/太融寺/南森町
172,02,関西,大阪,大阪駅/阪急梅田駅周辺
172,03,関西,大阪,北浜/本町
172,04,関西,大阪,京橋周辺
172,05,関西,大阪,十三/新大阪周辺
172,06,関西,大阪,心斎橋/堀江
172,08,関西,大阪,天王寺/あべの橋
172,10,関西,大阪,阿倍野/住吉/平野
172,12,関西,大阪,大阪南港
172,13,関西,大阪,北港/西淀川区
172,14,関西,大阪,阪急東通/天神橋筋商店街
172,15,関西,大阪,北新地/堂島/中之島
172,16,関西,大阪,大阪城周辺
172,17,関西,大阪,鶴橋/上本町/今里
172,18,関西,大阪,難波/日本橋
172,19,関西,大阪,大阪市北東部
172,20,関西,大阪,福島/野田
172,21,関西,大阪,土佐堀/江戸堀周辺
173,00,関西,大阪,池田/箕面/豊能郡
173,01,関西,大阪,豊中/吹田
173,02,関西,大阪,高槻/茨木/摂津
174,00,関西,大阪,枚方/寝屋川周辺
175,00,関西,大阪,東大阪
176,00,関西,兵庫,尼崎市
176,01,関西,兵庫,宝塚/伊丹/川西/三田
177,00,関西,兵庫,西宮市
178,00,関西,兵庫,芦屋市
179,00,関西,兵庫,神戸/ハーバーランド
179,01,関西,兵庫,元町
179,02,関西,兵庫,北野/新神戸
179,03,関西,兵庫,三宮/ポートアイランド
179,04,関西,兵庫,灘区
179,05,関西,兵庫,兵庫/長田
179,06,関西,兵庫,六甲山/有馬温泉
179,07,関西,兵庫,神戸西区
179,08,関西,兵庫,東灘/六甲アイランド
179,09,関西,兵庫,須磨/垂水
180,00,関西,兵庫,明石市
181,00,関西,兵庫,兵庫丹波
182,00,関西,兵庫,東播磨
182,01,関西,兵庫,北播磨
183,00,関西,兵庫,西播磨
184,00,関西,兵庫,姫路/中播磨
185,00,関西,兵庫,淡路島
186,00,中国,鳥取,鳥取
186,01,中国,鳥取,倉吉
186,02,中国,鳥取,米子/境港
191,00,中国,島根,松江/安来
191,01,中国,島根,出雲/雲南
191,02,中国,島根,大田
191,03,中国,島根,浜田/江津
191,04,中国,島根,益田
191,05,中国,島根,隠岐
197,00,中国,岡山,備前/瀬戸内
198,00,中国,岡山,岡山/玉野/赤磐
198,01,中国,岡山,高梁/新見
198,02,中国,岡山,津山/美作
199,00,中国,岡山,倉敷/総社/笠岡
200,00,中国,広島,福山/府中
200,01,中国,広島,三次/庄原
200,02,中国,広島,宮島/廿日市/大竹
200,03,中国,広島,呉/江田島
200,04,中国,広島,広島
200,05,中国,広島,東広島/西条/竹原
200,06,中国,広島,しまなみ海道
200,07,中国,広島,三原/尾道
200,08,中国,広島,北広島/安芸太田/安芸高田
205,00,中国,山口,宇部/山口/防府
205,01,中国,山口,萩/長門/秋芳
205,02,中国,山口,下関
205,03,中国,山口,周南/岩国
207,00,四国,香川,高松市周辺
208,00,四国,香川,東讃
209,00,四国,香川,中讃
210,00,四国,香川,西讃
211,00,四国,徳島,徳島市
212,00,四国,徳島,徳島県北部
213,00,四国,徳島,徳島県西部
214,00,四国,徳島,徳島県南部
215,00,四国,愛媛,中予
216,00,四国,愛媛,東予
217,00,四国,愛媛,南予北部
218,00,四国,愛媛,南予南部
219,00,四国,高知,高知市
220,00,四国,高知,高知県中部
221,00,四国,高知,高知県東部
222,00,四国,高知,高知県西部
223,00,九州,福岡,小倉北区
223,01,九州,福岡,門司区/小倉南区
223,02,九州,福岡,若松区/戸畑区/八幡東区
223,03,九州,福岡,八幡西区
223,04,九州,福岡,遠賀/筑豊
223,05,九州,福岡,京築
224,00,九州,福岡,中央区
224,01,九州,福岡,博多区/東区
224,02,九州,福岡,南区/城南区
224,03,九州,福岡,早良区/西区
224,04,九州,福岡,太宰府/筑紫野
224,05,九州,福岡,前原/糸島
224,06,九州,福岡,宗像/古賀/粕屋
225,00,九州,福岡,久留米/甘木
225,01,九州,福岡,柳川/大牟田/筑後
226,00,九州,佐賀,佐賀/鳥栖
227,00,九州,佐賀,唐津/伊万里
228,00,九州,長崎,壱岐/対馬
229,00,九州,長崎,佐世保/平戸
230,00,九州,長崎,五島
231,00,九州,長崎,長崎
232,00,九州,長崎,雲仙/島原
233,00,九州,熊本,天草
234,00,九州,熊本,熊本
234,01,九州,熊本,玉名/菊池
235,00,九州,大分,中津/日田
236,00,九州,大分,国東/宇佐
237,00,九州,大分,別府/湯布院/九重
238,00,九州,熊本,阿蘇/小国
239,00,九州,大分,大分
239,01,九州,大分,佐伯/竹田
240,00,九州,宮崎,延岡/日向
241,00,九州,宮崎,宮崎/日南
242,00,九州,宮崎,都城/小林
243,00,九州,熊本,八代/人吉/芦北
244,00,九州,鹿児島,鹿児島
244,01,九州,鹿児島,川内/出水
244,02,九州,鹿児島,国分/隼人
245,00,九州,鹿児島,指宿/枕崎
246,00,九州,鹿児島,鹿屋/垂水
247,00,九州,鹿児島,種子島/屋久島
248,00,九州,鹿児島,奄美
249,00,九州,沖縄,那覇/浦添
250,00,九州,沖縄,沖縄/名護
251,00,九州,沖縄,宮古/石垣
